@@ -392,7 +392,9 @@ class Destinations:
             backup_day=night_day
         else:
             backup_day=day
-        globals=dict(nday='%02d'%(night_day.day,), nmonth='%02d'%(night_day.month,), nyear=str(night_day.year,), nweekday=night_day.weekday(), nyearday='%03d'%(night_day.timetuple().tm_yday,),)
+            
+        globals=dict(os.environ)
+        globals.update(dict(nday='%02d'%(night_day.day,), nmonth='%02d'%(night_day.month,), nyear=str(night_day.year,), nweekday=night_day.weekday(), nyearday='%03d'%(night_day.timetuple().tm_yday,),))
         globals['nweekdayname']=night_day.strftime('%a')
         globals['nmonthname']=night_day.strftime('%b')
         
