@@ -35,7 +35,7 @@ from archiver import boolean, check_mail_config, Destinations, sendmail, Manager
 
 import cron
 
-__version__='0.9.5'
+__version__='0.9.6'
 last_version_url='http://www.magikmon.com/download/mkbackup_last.txt'
 
 def gen_archiver(name):
@@ -58,11 +58,10 @@ def gen_archiver(name):
     else:
         return None
 
-
 # ---------------------------------------------------------------------------
 def update_check():
-    """Check if and new version of MKBackup is available and return the annonce
-    message if available
+    """Check if and new version of MKBackup is available and return the
+    announcement message if available
     """
     up2date, msg='yes', ''
     try:
@@ -83,8 +82,6 @@ def update_check():
 
     return up2date, msg
 
-
-
 # ---------------------------------------------------------------------------        
 def mail_exception(start, job, extra, manager, subject):
     
